@@ -227,6 +227,7 @@ void command_property(gpointer callback_data,guint callback_action,
 	ft.limit=ptw->limit;
 	ft.overwrite=ptw->overwrite;
 	ft.space=ptw->space;
+	ft.syscol=ptw->syscol;
 	ft.gline=ptw->gline;
 	ft.mline=ptw->mline;
 	ft.uline=ptw->uline;
@@ -251,6 +252,7 @@ void command_property(gpointer callback_data,guint callback_action,
 					ftype[i].limit=ft.limit;
 					ftype[i].overwrite=ft.overwrite;
 					ftype[i].space=ft.space;
+					ftype[i].syscol=ft.syscol;
 					ftype[i].gline=ft.gline;
 					ftype[i].mline=ft.mline;
 					ftype[i].uline=ft.uline;
