@@ -269,6 +269,7 @@ TEXTWND *open_edit_file(gchar *file)
 		ptw->limit=ftype[0].limit;
 		ptw->overwrite=ftype[0].overwrite;
 		ptw->space=ftype[0].space;
+		ptw->syscol=ftype[0].syscol;
 		ptw->gline=ftype[0].gline;
 		ptw->mline=ftype[0].mline;
 		ptw->uline=ftype[0].uline;
@@ -302,6 +303,7 @@ TEXTWND *open_edit_file(gchar *file)
 		ptw->limit=ftype[i].limit;
 		ptw->overwrite=ftype[i].overwrite;
 		ptw->space=ftype[i].space;
+		ptw->syscol=ftype[i].syscol;
 		ptw->gline=ftype[i].gline;
 		ptw->mline=ftype[i].mline;
 		ptw->uline=ftype[i].uline;
