@@ -100,11 +100,7 @@ void draw_caret(TEXTWND *ptw,GdkPoint *cursor)
 					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
 		ptw->ic_attr->spot_location.x=rc.x;
 		ptw->ic_attr->spot_location.y=rc.y+ptw->fontascent;
-		ptw->ic_attr->preedit_foreground=ptw->color[0];
-		ptw->ic_attr->preedit_background=ptw->color[1];
-		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_SPOT_LOCATION
-					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
-
+		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_SPOT_LOCATION);
 	}
 #endif
 }
@@ -395,6 +391,25 @@ DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 }
 
 
+/*	ꥹȤ
+	  d,ꥹȤƬ
+	RET,ꥹȤο													*/
+gint delete_list(DOING **d)
+{
+	gint count=0;
+	DOING *d0,*d1;
+
+	for (d0=*d;d0!=NULL;d0=d1) {
+		g_free(d0->text);
+		d1=d0->next;
+		g_free(d0);
+		count++;
+	}
+	*d=NULL;
+	return count;
+}
+
+
 /*	ޡޤ֤
 	ptw,TXTɥ													*/
 void modify_margin(TEXTWND *ptw)
@@ -487,11 +502,89 @@ void modify_margin(TEXTWND *ptw)
 }
 
 
-/******************************************************************************
-*                                                                             *
-* ٥ؿ                                                              *
-*                                                                             *
-******************************************************************************/
+/*	ץѥƥѹ
+	ptw,TXTɥ
+	 ft,ե륿														*/
+void change_property(TEXTWND *ptw,FTYPE *ft)
+{
+	gboolean modify;
+	gint i,fontsize,lbearing,rbearing,width,ascent,descent;
+	gint max,sx,sy;
+
+	if (ptw->limit!=ft->limit || ptw->tab!=ft->tab
+								|| (ptw->code && ptw->margin!=ft->margin)) {
+		/* ޤ֤ѹֿѹ */
+		delete_list(&ptw->undo);
+		delete_list(&ptw->redo);
+	}
+	modify=ptw->limit!=ft->limit || (ptw->limit
+							&& (ptw->tab!=ft->tab || ptw->margin!=ft->margin));
+	ptw->ft_id=ft->ft_id;
+	ptw->margin=ft->margin;
+	ptw->tab=ft->tab;
+	ptw->code=ft->code;
+	ptw->crlf=ft->crlf;
+	ptw->eof=ft->eof;
+	ptw->limit=ft->limit;
+	ptw->overwrite=ft->overwrite;
+	ptw->space=ft->space;
+	ptw->syscol=ft->syscol;
+	ptw->gline=ft->gline;
+	ptw->mline=ft->mline;
+	ptw->uline=ft->uline;
+	ptw->vline=ft->vline;
+	g_free(ptw->fontname);
+	ptw->fontname=g_strdup(ft->fontname);
+	memcpy(ptw->color,ft->color,sizeof(GdkColor)*12);
+	ptw->select.x=-1;
+	if (modify) {
+		/* ޤ֤ѹޤ֤ͭǥֿѹ */
+		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
+		modify_margin(ptw);
+	}
+	/* ե */
+	gdk_font_unref(ptw->font);
+	ptw->font=gdk_fontset_load(ptw->fontname);
+	ptw->fontascent=ptw->fontsize=0;
+	for (i=0x20;i<=0x7e;i++) {
+		gdk_text_extents(ptw->font,(gchar *)&i,1,
+								&lbearing,&rbearing,&width,&ascent,&descent);
+		if (ptw->fontascent<ascent)
+			ptw->fontascent=ascent;
+		fontsize=(gdk_char_height(ptw->font,i)+1)/2;
+		if (ptw->fontsize<fontsize)
+			ptw->fontsize=fontsize;
+	}
+	/* С */
+	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
+	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
+	if (ptw->top.y>ptw->max-sy)
+		ptw->top.y=MAX(ptw->max-sy,0);
+	max=get_width_max(ptw);
+	if (ptw->top.x>max-sx+1)
+		ptw->top.x=MAX(max-sx+1,0);
+	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+												0,max,sx,ptw->top.x);
+	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+												0,ptw->max-1,sy,ptw->top.y);
+	/*  */
+	gtk_widget_draw(ptw->drawing,NULL);
+	draw_caret(ptw,NULL);
+#ifdef USE_XIM
+	if (gdk_im_ready() && ptw->ic!=NULL
+					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
+		ptw->ic_attr->preedit_foreground=ptw->syscol
+												?system_color[0]:ptw->color[0];
+		ptw->ic_attr->preedit_background=ptw->syscol
+												?system_color[1]:ptw->color[1];
+		ptw->ic_attr->preedit_fontset=ptw->font;
+		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FONTSET
+					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
+	}
+#endif
+}
+
+
 /*	ե¸䤤碌
 	ptw,TXTɥ
 	RET,TRUE:եĤ,FALSE:եĤʤ						*/
@@ -520,25 +613,11 @@ gboolean prompt_close(TEXTWND *ptw)
 }
 
 
-/*	ꥹȤ
-	  d,ꥹȤƬ
-	RET,ꥹȤο													*/
-gint delete_list(DOING **d)
-{
-	gint count=0;
-	DOING *d0,*d1;
-
-	for (d0=*d;d0!=NULL;d0=d1) {
-		g_free(d0->text);
-		d1=d0->next;
-		g_free(d0);
-		count++;
-	}
-	*d=NULL;
-	return count;
-}
-
-
+/******************************************************************************
+*                                                                             *
+* ٥ؿ                                                              *
+*                                                                             *
+******************************************************************************/
 /*	Խ
 	 ptw,TXTɥ
 	kind,TRUE:redo,FALSE:undo												*/
@@ -662,126 +741,3 @@ void tab_operation(TEXTWND *ptw)
 	set_menu_bar(ptw);
 	gtk_widget_draw(ptw->drawing,NULL);
 }
-
-
-/*	Ԥذư
-	 ptw,TXTɥ
-	line,(1...)														*/
-void jump_operation(TEXTWND *ptw,gint line)
-{
-	gint sx,sy;
-	GdkPoint cursor,select,top;
-
-	cursor=ptw->cursor;
-	select=ptw->select;
-	top=ptw->top;
-	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
-	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
-	ptw->cursor.y=line<0?ptw->max+line:line-1;
-	if (ptw->cursor.y<0)
-		ptw->cursor.y=0;
-	else if (ptw->cursor.y>ptw->max-1)
-		ptw->cursor.y=ptw->max-1;
-	if (ptw->cursor.x<ptw->top.x)
-		ptw->top.x=ptw->cursor.x;
-	else if (ptw->cursor.x-sx+1>ptw->top.x)
-		ptw->top.x=ptw->cursor.x-sx+1;
-	if (ptw->cursor.y<ptw->top.y)
-		ptw->top.y=ptw->cursor.y;
-	else if (ptw->cursor.y-sy+1>ptw->top.y)
-		ptw->top.y=ptw->cursor.y-sy+1;
-	move_text_window(ptw,&top);
-	if (ptw->select.x>=0) {
-		if (ptw->select.y==ptw->cursor.y
-						&& ptw->select.x==get_align_pos(&ptw->start,&ptw->off,
-								ptw->cursor.x,ptw->cursor.y,ptw->tab,FALSE)) {
-			ptw->select.x=-1;
-			clear_sel(ptw,&select,&cursor);
-			set_menu_bar(ptw);
-		} else {
-			clear_sel(ptw,&ptw->cursor,&cursor);
-		}
-	}
-	draw_caret(ptw,&cursor);
-}
-
-
-/*	ץѥƥѹ
-	ptw,TXTɥ
-	 ft,ե륿														*/
-void change_property(TEXTWND *ptw,FTYPE *ft)
-{
-	gboolean modify;
-	gint i,fontsize,lbearing,rbearing,width,ascent,descent;
-	gint max,sx,sy;
-	GdkRectangle rc;
-
-	if (ptw->limit!=ft->limit || ptw->tab!=ft->tab
-								|| (ptw->code && ptw->margin!=ft->margin)) {
-		/* ޤ֤ѹֿѹ */
-		delete_list(&ptw->undo);
-		delete_list(&ptw->redo);
-	}
-	modify=ptw->limit!=ft->limit || (ptw->limit
-							&& (ptw->tab!=ft->tab || ptw->margin!=ft->margin));
-	ptw->ft_id=ft->ft_id;
-	ptw->margin=ft->margin;
-	ptw->tab=ft->tab;
-	ptw->code=ft->code;
-	ptw->crlf=ft->crlf;
-	ptw->eof=ft->eof;
-	ptw->limit=ft->limit;
-	ptw->overwrite=ft->overwrite;
-	ptw->space=ft->space;
-	ptw->gline=ft->gline;
-	ptw->mline=ft->mline;
-	ptw->uline=ft->uline;
-	ptw->vline=ft->vline;
-	g_free(ptw->fontname);
-	ptw->fontname=g_strdup(ft->fontname);
-	memcpy(ptw->color,ft->color,sizeof(GdkColor)*12);
-	ptw->select.x=-1;
-	if (modify) {
-		/* ޤ֤ѹޤ֤ͭǥֿѹ */
-		ptw->cursor.x=ptw->cursor.y=ptw->top.x=ptw->top.y=0;
-		modify_margin(ptw);
-	}
-	/* ե */
-	gdk_font_unref(ptw->font);
-	ptw->font=gdk_fontset_load(ptw->fontname);
-	ptw->fontascent=ptw->fontsize=0;
-	for (i=0x20;i<=0x7e;i++) {
-		gdk_text_extents(ptw->font,(gchar *)&i,1,
-								&lbearing,&rbearing,&width,&ascent,&descent);
-		if (ptw->fontascent<ascent)
-			ptw->fontascent=ascent;
-		fontsize=(gdk_char_height(ptw->font,i)+1)/2;
-		if (ptw->fontsize<fontsize)
-			ptw->fontsize=fontsize;
-	}
-	/* С */
-	sx=MAX(ptw->drawing->allocation.width/ptw->fontsize,1);
-	sy=MAX(ptw->drawing->allocation.height/(ptw->fontsize*2),1);
-	if (ptw->top.y>ptw->max-sy)
-		ptw->top.y=MAX(ptw->max-sy,0);
-	max=get_width_max(ptw);
-	if (ptw->top.x>max-sx+1)
-		ptw->top.x=MAX(max-sx+1,0);
-#ifdef USE_XIM
-	if (gdk_im_ready() && ptw->ic!=NULL
-					&& (gdk_ic_get_style(ptw->ic)&GDK_IM_PREEDIT_POSITION)) {
-		ptw->ic_attr->preedit_fontset=ptw->font;
-		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,GDK_IC_PREEDIT_FONTSET);
-	}
-#endif
-	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-												0,max,sx,ptw->top.x);
-	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-												0,ptw->max-1,sy,ptw->top.y);
-	/*  */
-	rc.x=rc.y=0;
-	rc.width=ptw->drawing->allocation.width;
-	rc.height=ptw->drawing->allocation.height;
-	gtk_widget_draw(ptw->drawing,&rc);
-	draw_caret(ptw,NULL);
-}
