@@ -32,8 +32,8 @@ static gint ft_id;
 static GdkColor gdk_color[12];
 static GtkWidget *dialog;
 static GtkWidget *button0,*button3;
-static GtkWidget *check0,*check1,*check2,*check3,*check4;
-static GtkWidget *check5,*check6,*check7,*check8,*check9,*check10;
+static GtkWidget *check0,*check1,*check2,*check3,*check4,*check5;
+static GtkWidget *check6,*check7,*check8,*check9,*check10,*check11;
 static GtkWidget *clist,*entry0,*entry1,*label,*spin0,*spin1;
 static gchar *color_name[12]={N_("ʸ"),N_("ط"),N_("ȥ륳"),
 		N_("ѥڡ"),N_("ԥ"),N_("ֲ"),
@@ -50,6 +50,17 @@ static void property_dialog_ok_sensitive(GtkWidget *widget,gpointer user_data)
 }
 
 
+/* ƥ࿧ */
+static void property_dialog_toggled(GtkWidget *widget,gpointer user_data)
+{
+	gtk_clist_unselect_all(GTK_CLIST(clist));
+	gtk_widget_set_sensitive(clist,
+					!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10)));
+	gtk_widget_set_sensitive(button0,FALSE);
+	property_dialog_ok_sensitive(widget,user_data);
+}
+
+
 /* ꥹȥܥå */
 static void property_dialog_select_row(GtkWidget *widget,
 				gint row,gint column,GdkEventButton *event,gpointer user_data)
@@ -207,6 +218,8 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
 														ftype[pos].eof);
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),
 														ftype[pos].overwrite);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),
+														ftype[pos].syscol);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),
 														ftype[pos].margin);
 			gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
@@ -247,8 +260,9 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FTYPE *ft)
 	ft->vline=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check7));
 	ft->eof=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check8));
 	ft->overwrite=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check9));
-	if (check10!=NULL)
-		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10));
+	ft->syscol=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check10));
+	if (check11!=NULL)
+		ft->associate=gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check11));
 	memcpy(ft->color,gdk_color,sizeof(GdkColor)*12);
 	g_free(ft->fontname);
 	ft->fontname=fontname;
@@ -283,7 +297,7 @@ gboolean property_dialog(FTYPE *ft)
 	gint i;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	GtkWidget *button1,*button2,*button4;
+	GtkWidget *button1,*button2,*button4,*scroll;
 	GtkWidget *hbox,*tbox,*vbox;
 	GtkWidget *frame0,*frame1,*frame2,*frame3,*frame4;
 
@@ -325,6 +339,7 @@ gboolean property_dialog(FTYPE *ft)
 	check8=gtk_check_button_new_with_label(
 										_("եκǸ^Z(1A)դ"));
 	check9=gtk_check_button_new_with_label(_("¸ǧ"));
+	check10=gtk_check_button_new_with_label(_("ƥ࿧Ȥ"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),ft->gline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),ft->space);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check2),ft->crlf);
@@ -335,6 +350,7 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check7),ft->vline);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check8),ft->eof);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check9),ft->overwrite);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),ft->syscol);
 	gtk_signal_connect(GTK_OBJECT(check0),"toggled",
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(check1),"toggled",
@@ -355,14 +371,16 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_ok_sensitive,NULL);
 	gtk_signal_connect(GTK_OBJECT(check9),"toggled",
 											property_dialog_ok_sensitive,NULL);
+	gtk_signal_connect(GTK_OBJECT(check10),"toggled",
+											property_dialog_toggled,NULL);
 	if (ft->text!=NULL && ft->ext!=NULL) {
-		check10=gtk_check_button_new_with_label(
+		check11=gtk_check_button_new_with_label(
 											_("ե륿פϢŤ"));
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check10),ft->associate);
-		gtk_signal_connect(GTK_OBJECT(check10),"toggled",
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check11),ft->associate);
+		gtk_signal_connect(GTK_OBJECT(check11),"toggled",
 											property_dialog_ok_sensitive,NULL);
 	} else {
-		check10=NULL;
+		check11=NULL;
 	}
 	/* ȥ꡼/٥ */
 	label=NULL;
@@ -413,6 +431,11 @@ gboolean property_dialog(FTYPE *ft)
 											property_dialog_select_row,NULL);
 	gtk_signal_connect(GTK_OBJECT(clist),"unselect-row",
 											property_dialog_unselect_row,NULL);
+	/* 륦ɥ */
+	scroll=gtk_scrolled_window_new(NULL,NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
+										GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroll),clist);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(
 		GTK_ADJUSTMENT(gtk_adjustment_new(ft->margin,1,G_MAXINT,1,5,0)),0,0);
@@ -487,11 +510,14 @@ gboolean property_dialog(FTYPE *ft)
 	frame4=gtk_frame_new(_(""));
 	vbox=gtk_vbox_new(FALSE,0);
 	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),clist,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(hbox),scroll,TRUE,TRUE,8);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
 	hbox=gtk_hbox_new(FALSE,0);
+	gtk_box_pack_start(GTK_BOX(hbox),check10,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
+	hbox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,7);
+	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
 	gtk_container_add(GTK_CONTAINER(frame4),vbox);
 
 	vbox=gtk_vbox_new(FALSE,8);
@@ -511,8 +537,8 @@ gboolean property_dialog(FTYPE *ft)
 	gtk_box_pack_start(GTK_BOX(hbox),button1,FALSE,FALSE,8);
 	if (button2!=NULL)
 		gtk_box_pack_start(GTK_BOX(hbox),button2,FALSE,FALSE,8);
-	if (check10!=NULL)
-		gtk_box_pack_start(GTK_BOX(hbox),check10,FALSE,FALSE,8);
+	if (check11!=NULL)
+		gtk_box_pack_start(GTK_BOX(hbox),check11,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button4,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button3,FALSE,FALSE,8);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,8);
@@ -522,6 +548,7 @@ gboolean property_dialog(FTYPE *ft)
 	/* ɽ */
 	gtk_widget_set_sensitive(button0,FALSE);
 	gtk_widget_set_sensitive(button3,FALSE);
+	gtk_widget_set_sensitive(clist,!ft->syscol);
 	gtk_widget_grab_focus(button4);
 
 	ft_id=ft->ft_id;
