@@ -21,10 +21,10 @@
 #include "replace.h"
 
 
-gboolean replace_arrow=TRUE;				/* /ִ */
+gboolean replace_arrow=TRUE;				/* ִ */
 gboolean replace_ignorecase=FALSE;			/* ִ */
 gchar *replace_text[32];					/* ִʸ */
-gint replace_num=0;							/* ϿƤ븡/ִʸ */
+gint replace_num=0;							/* ϿƤִʸ */
 
 
 /******************************************************************************
