@@ -81,8 +81,7 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 	if (gdk_im_ready() && (ptw->ic_attr=gdk_ic_attr_new())!=NULL) {
 		gint width, height;
 		GdkColormap *colormap;
-		GdkICAttributesType attrmask=GDK_IC_ALL_REQ
-					| GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND;
+		GdkICAttributesType attrmask=GDK_IC_ALL_REQ;
 		GdkIMStyle supported_style=GDK_IM_PREEDIT_NONE
 									| GDK_IM_PREEDIT_NOTHING
 									| GDK_IM_STATUS_NONE
@@ -97,8 +96,6 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 			attrmask|=GDK_IC_PREEDIT_COLORMAP;
 			ptw->ic_attr->preedit_colormap=colormap;
 		}
-		ptw->ic_attr->preedit_foreground=ptw->color[0];
-		ptw->ic_attr->preedit_background=ptw->color[1];
 		switch (ptw->ic_attr->style&GDK_IM_PREEDIT_MASK) {
 			case GDK_IM_PREEDIT_POSITION:
 				if (ptw->font->type==GDK_FONT_FONTSET) {
@@ -119,6 +116,12 @@ void signal_realize(GtkWidget *widget,TEXTWND *ptw)
 			if (GTK_WIDGET_HAS_FOCUS(ptw->drawing))
 				gdk_im_begin(ptw->ic,ptw->drawing->window);
 		}
+		ptw->ic_attr->preedit_foreground=ptw->syscol
+												?system_color[0]:ptw->color[0];
+		ptw->ic_attr->preedit_background=ptw->syscol
+												?system_color[1]:ptw->color[1];
+		gdk_ic_set_attr(ptw->ic,ptw->ic_attr,
+						GDK_IC_PREEDIT_FOREGROUND | GDK_IC_PREEDIT_BACKGROUND);
 	}
 #endif
 }
@@ -206,8 +209,9 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 	gc=gdk_gc_new(widget->window);
 	gdk_gc_set_line_attributes(gc,1,
 								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
-	for (i=0;i<12;i++)
-		gdk_color_alloc(gdk_colormap_get_system(),ptw->color+i);
+	for (i=0;i<10;i++)
+		gdk_color_alloc(gdk_colormap_get_system(),
+									(ptw->syscol?system_color:ptw->color)+i);
 	cursor.x=get_align_pos(&ptw->start,&ptw->off,ptw->cursor.x,ptw->cursor.y,
 															ptw->tab,FALSE);
 	cursor.y=ptw->cursor.y;
@@ -225,12 +229,12 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 		end=ptw->select;
 	}
 	/* ط */
-	gdk_gc_set_foreground(gc,ptw->color+1);
+	gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+1);
 	gdk_draw_rectangle(widget->window,gc,TRUE,event->area.x,event->area.y,
 										event->area.width,event->area.height);
 	if (ptw->gline) {
 		/* å */
-		gdk_gc_set_foreground(gc,ptw->color+7);
+		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+7);
 		for (x=ptw->fontsize-1;x<widget->allocation.width;x+=ptw->fontsize)
 			gdk_draw_line(widget->window,gc,x,event->area.y,
 										x,event->area.y+event->area.height);
@@ -241,7 +245,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 	}
 	if (ptw->vline) {
 		/*  */
-		gdk_gc_set_foreground(gc,ptw->color+7);
+		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+7);
 		for (x=(ptw->tab-ptw->top.x%ptw->tab)*ptw->fontsize-1;
 						x<widget->allocation.width;x+=ptw->fontsize*ptw->tab)
 			gdk_draw_line(widget->window,gc,x,event->area.y,
@@ -249,7 +253,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 	}
 	if (ptw->mline) {
 		/* ޡ */
-		gdk_gc_set_foreground(gc,ptw->color+6);
+		gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)+6);
 		x=(ptw->margin-ptw->top.x)*ptw->fontsize;
 		gdk_draw_line(widget->window,gc,x,event->area.y,
 										x,event->area.y+event->area.height);
@@ -298,19 +302,22 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 										*ptw->tab-ptw->top.x)*ptw->fontsize-x;
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,ptw->color+9);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 														width,ptw->fontsize*2);
 				}
 				if (ptw->uline) {
 					/*  */
-					gdk_gc_set_foreground(gc,ptw->color+5);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+5);
 					gdk_draw_line(widget->window,gc,x,y+ptw->fontsize*2-1,
 												x+width,y+ptw->fontsize*2-1);
 				}
 				if (ptw->code) {
 					/* ʸ */
-					gdk_gc_set_foreground(gc,ptw->color+2);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+2);
 					gdk_draw_rectangle(widget->window,gc,FALSE,
 										x+ptw->fontsize/6,y+ptw->fontsize*2/3,
 										ptw->fontsize*2/3,ptw->fontsize*2/3);
@@ -321,12 +328,15 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 				width=ptw->fontsize;
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,ptw->color+9);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 														width,ptw->fontsize*2);
-					gdk_gc_set_foreground(gc,ptw->color+8);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+8);
 				} else {
-					gdk_gc_set_foreground(gc,ptw->color);
+					gdk_gc_set_foreground(gc,
+									ptw->syscol?system_color:ptw->color);
 				}
 				gdk_draw_text(widget->window,ptw->font,gc,
 										x,y+ptw->fontascent,p->text+datapos,1);
@@ -336,17 +346,21 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 				width=ptw->fontsize*2;
 				if (select) {
 					/*  */
-					gdk_gc_set_foreground(gc,ptw->color+9);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+9);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 														width,ptw->fontsize*2);
-					gdk_gc_set_foreground(gc,ptw->color+8);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+8);
 				} else {
-					gdk_gc_set_foreground(gc,ptw->color);
+					gdk_gc_set_foreground(gc,
+									ptw->syscol?system_color:ptw->color);
 				}
 				if (ptw->space && (guchar)p->text[datapos]==0xa1
 										&& (guchar)p->text[datapos+1]==0xa1) {
 					/* ѥڡ */
-					gdk_gc_set_foreground(gc,ptw->color+3);
+					gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+3);
 					gdk_draw_rectangle(widget->window,gc,TRUE,x+1,y+1,
 													width-1,ptw->fontsize*2-1);
 				} else {
@@ -360,7 +374,8 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 			if (caret && GTK_WIDGET_HAS_FOCUS(widget)
 								&& cursor.x==ptw->top.x+x/ptw->fontsize
 								&& cursor.y==ptw->top.y+y/(ptw->fontsize*2)) {
-				gdk_gc_set_foreground(gc,ptw->color+(select?8:0));
+				gdk_gc_set_foreground(gc,
+						(ptw->syscol?system_color:ptw->color)+(select?8:0));
 				gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 										ins?2:ptw->fontsize,ptw->fontsize*2);
 			}
@@ -370,11 +385,13 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 			if (start.x>=0 && start.y<=ptw->top.y+y/(ptw->fontsize*2)
 									&& ptw->top.y+y/(ptw->fontsize*2)<end.y) {
 				/*  */
-				gdk_gc_set_foreground(gc,ptw->color+9);
+				gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+9);
 				gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
 												ptw->fontsize,ptw->fontsize*2);
 			}
-			gdk_gc_set_foreground(gc,ptw->color+4);
+			gdk_gc_set_foreground(gc,
+									(ptw->syscol?system_color:ptw->color)+4);
 			if (p->next==NULL) {
 				/* եκǸ */
 				gdk_draw_arc(widget->window,gc,TRUE,
@@ -404,7 +421,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,TEXTWND *ptw)
 		if (caret && GTK_WIDGET_HAS_FOCUS(widget)
 								&& cursor.x==ptw->top.x+x/ptw->fontsize
 								&& cursor.y==ptw->top.y+y/(ptw->fontsize*2)) {
-			gdk_gc_set_foreground(gc,ptw->color
+			gdk_gc_set_foreground(gc,(ptw->syscol?system_color:ptw->color)
 						+(start.x>=0 && start.y<=ptw->top.y+y/(ptw->fontsize*2)
 								&& ptw->top.y+y/(ptw->fontsize*2)<end.y?8:0));
 			gdk_draw_rectangle(widget->window,gc,TRUE,x,y,
@@ -1141,6 +1158,38 @@ void signal_destroy_draw(GtkWidget *widget,TEXTWND *ptw)
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ʥ/٥ȴؿ(ƥ)                                           *
+*                                                                             *
+******************************************************************************/
+void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
+{
+	gint i;
+	GList *glist;
+	TEXTWND *ptw;
+
+	style=gtk_widget_get_style(widget);
+	system_color[ 0]=style->text[0];
+	system_color[ 1]=style->base[0];
+	system_color[ 2]=style->dark[0];
+	system_color[ 3]=style->dark[0];
+	system_color[ 4]=style->dark[0];
+	system_color[ 5]=style->dark[0];
+	system_color[ 6]=style->dark[0];
+	system_color[ 7]=style->mid[0];
+	system_color[ 8]=style->fg[3];
+	system_color[ 9]=style->bg[3];
+	glist=gtk_container_children(GTK_CONTAINER(notebook));
+	for (i=g_list_length(glist)-1;i>=0;i--) {
+		ptw=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
+		if (ptw->syscol)
+			gtk_widget_draw(ptw->drawing,NULL);
+	}
+	g_list_free(glist);
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ʥ/٥ȴؿ(˥塼)                                           *
