@@ -26,6 +26,7 @@
 #include "find.h"
 #include "format.h"
 #include "general.h"
+#include "jump.h"
 #include "other.h"
 #include "profile.h"
 #include "replace.h"
@@ -52,6 +53,12 @@ GtkWidget *notebook;				/* Ρȥ֥å */
 GtkWidget *status;					/* ơɥ */
 GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
+GdkColor system_color[12]={	{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
+							{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
+							{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
+							{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
+							{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
+							{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
 
 
 /******************************************************************************
@@ -70,13 +77,8 @@ int main(int argc,char *argv[])
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
-	GtkWidget *menubar,*toolbar,*sub_menu,*menu_item,*vbox;
-	GdkColor color[12]={{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
-						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
-						{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
-						{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
-						{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
-						{0,0x0000,0x0000,0x0000},{0,0x8000,0x8000,0x8000}};
+	GtkStyle *style;
+	GtkWidget *text,*menubar,*toolbar,*sub_menu,*menu_item,*vbox;
 	GtkItemFactoryEntry menu_items[]={
 {N_("/ե(_F)"),                               NULL,         NULL,            0,"<Branch>"},
 {N_("/ե(F)/(_N)"),                   "<control>N", command_new,     0,"<Item>"},
@@ -276,6 +278,10 @@ int main(int argc,char *argv[])
 								(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].space=FALSE;
+			if (!profile_get_value(profile,section,"syscol",
+								(gpointer)&ftype[i].syscol,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].syscol=TRUE;
 			if (!profile_get_value(profile,section,"gline",
 								(gpointer)&ftype[i].gline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -302,7 +308,7 @@ int main(int argc,char *argv[])
 			if (!profile_get_value(profile,section,"color",
 								(gpointer)&ftype[i].color,sizeof(GdkColor)*12,
 													PROFILE_VALUE_TYPE_ARRAY))
-				memcpy(ftype[i].color,color,sizeof(GdkColor)*12);
+				memcpy(ftype[i].color,system_color,sizeof(GdkColor)*12);
 			g_free(section);
 		}
 		profile_close(profile);
@@ -404,33 +410,29 @@ int main(int argc,char *argv[])
 
 	/* ե륿 */
 	if (ftnum<=0) {
-		ftnum=2;
+		ftnum=1;
 		ftype=g_malloc(ftnum*sizeof(FTYPE));
-		ftype[0].text=g_strdup(_("ƥȥե"));
-		ftype[0].ext=g_strdup(".txt");
-		ftype[1].text=g_strdup(_("٤ƤΥե"));
-		ftype[1].ext=g_strdup("*");
-		ftype[0].margin=ftype[1].margin=80;
-		ftype[0].tab=ftype[1].tab=8;
-		ftype[0].associate=ftype[1].associate=TRUE;
-		ftype[0].code=ftype[1].code=FALSE;
-		ftype[0].crlf=ftype[1].crlf=FALSE;
-		ftype[0].eof=ftype[1].eof=FALSE;
-		ftype[0].limit=ftype[1].limit=FALSE;
-		ftype[0].overwrite=ftype[1].overwrite=FALSE;
-		ftype[0].space=ftype[1].space=FALSE;
-		ftype[0].gline=ftype[1].gline=FALSE;
-		ftype[0].mline=ftype[1].mline=FALSE;
-		ftype[0].uline=ftype[1].uline=FALSE;
-		ftype[0].vline=ftype[1].vline=FALSE;
+		ftype[0].text=g_strdup(_("٤ƤΥե"));
+		ftype[0].ext=g_strdup("*");
+		ftype[0].margin=80;
+		ftype[0].tab=8;
+		ftype[0].associate=TRUE;
+		ftype[0].code=FALSE;
+		ftype[0].crlf=FALSE;
+		ftype[0].eof=FALSE;
+		ftype[0].limit=FALSE;
+		ftype[0].overwrite=FALSE;
+		ftype[0].space=FALSE;
+		ftype[0].syscol=TRUE;
+		ftype[0].gline=FALSE;
+		ftype[0].mline=FALSE;
+		ftype[0].uline=FALSE;
+		ftype[0].vline=FALSE;
 		/* ե */
 		ftype[0].fontname=g_strdup("-*-*-*-r-normal-*-16-*-*-*-*-*-iso8859-1,"
 							"-*-*-*-r-normal-*-16-*-*-*-*-*-jisx0208.1983-0");
-		ftype[1].fontname=g_strdup("-*-*-*-r-normal-*-16-*-*-*-*-*-iso8859-1,"
-							"-*-*-*-r-normal-*-16-*-*-*-*-*-jisx0208.1983-0");
 		/*  */
-		memcpy(ftype[0].color,color,sizeof(GdkColor)*12);
-		memcpy(ftype[1].color,color,sizeof(GdkColor)*12);
+		memcpy(ftype[0].color,system_color,sizeof(GdkColor)*12);
 	}
 
 	/* ᥤ󥦥ɥ */
@@ -442,6 +444,22 @@ int main(int argc,char *argv[])
 	gtk_signal_connect(GTK_OBJECT(window),"destroy",
 												signal_destroy_window,NULL);
 	gtk_widget_show(window);
+	/* ƥ */
+	text=gtk_text_new(NULL,NULL);
+	gtk_widget_set_parent(text,window);
+	gtk_widget_realize(text);
+	gtk_signal_connect(GTK_OBJECT(text),"style-set",signal_style_set,NULL);
+	style=gtk_widget_get_style(text);
+	system_color[ 0]=style->text[0];
+	system_color[ 1]=style->base[0];
+	system_color[ 2]=style->dark[0];
+	system_color[ 3]=style->dark[0];
+	system_color[ 4]=style->dark[0];
+	system_color[ 5]=style->dark[0];
+	system_color[ 6]=style->dark[0];
+	system_color[ 7]=style->mid[0];
+	system_color[ 8]=style->fg[3];
+	system_color[ 9]=style->bg[3];
 	/* Drag and Drop */
 	gtk_drag_dest_set(window,GTK_DEST_DEFAULT_MOTION
 						| GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
@@ -514,7 +532,7 @@ int main(int argc,char *argv[])
 		gtk_object_set_user_data(GTK_OBJECT(menu_item),hisfile[i]);
 		gtk_menu_insert(GTK_MENU(sub_menu),menu_item,i+MENUFILE-1);
 	}
-	if (i!=0)
+	if (i>0)
 		gtk_menu_insert(GTK_MENU(sub_menu),gtk_menu_item_new(),i+MENUFILE-1);
 	/*  */
 	timer_id=gtk_timeout_add(500,signal_timeout,NULL);
@@ -646,6 +664,9 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"space",
 								(gpointer)&ftype[i].space,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value(profile,section,"syscol",
+								(gpointer)&ftype[i].syscol,sizeof(gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"gline",
 								(gpointer)&ftype[i].gline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
