@@ -44,6 +44,7 @@ typedef struct ftype {
 	gboolean limit;				/* TRUE:ޡޤ֤ */
 	gboolean overwrite;			/* TRUE:ե񤭤Ȥ˳ǧ */
 	gboolean space;				/* TRUE:ڡ򳥿λͳѤɽ */
+	gboolean syscol;			/* TRUE:ƥ࿧Ȥ */
 	gboolean gline;				/* TRUE:åɽ */
 	gboolean mline;				/* TRUE:ޡɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
@@ -78,6 +79,7 @@ typedef struct textwnd {
 	gboolean limit;				/* TRUE:ޡޤ֤ */
 	gboolean overwrite;			/* TRUE:ե񤭤Ȥ˳ǧ */
 	gboolean space;				/* TRUE:ڡ򳥿λͳѤɽ */
+	gboolean syscol;			/* TRUE:ƥ࿧Ȥ */
 	gboolean gline;				/* TRUE:åɽ */
 	gboolean mline;				/* TRUE:ޡɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
@@ -132,6 +134,7 @@ extern GtkWidget *notebook;				/* Ρȥ֥å */
 extern GtkWidget *status;				/* ơɥ */
 extern GtkItemFactory *item_factory_menu;	/* ˥塼 */
 extern GtkItemFactory *item_factory_popup;	/* ݥåץå */
+extern GdkColor system_color[12];
 
 
 #endif
